/*  briefomat 
 *  Copyright (C) 1999 Stefan Heimers (stefan.heimers@kosta.ch)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 
 *  59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

/*
configs.c
Functions to setup default settings.

init_config_defaults() tries to guess default settings so that the
user or administrator doesn't need to configure them by hand. 

init_config_globalfile() reads configurations from a global
config-file (/etc/briefomatrc) which is edited by the administrator to
set system wide defaults. It overrides the defaults.

init_config_personalfile() reads configurations from ~/.briefomatrc
which the user can edit. It overrides defaults and globalfile 

*/


#include <stdlib.h>
#include "briefomat.h"
#include "configs.h"
#include "parser.h"

void init_config()
{
  char buffer[1000];
  init_config_defaults(); //these 3 functions are below
  init_config_globalfile();
  init_config_personalfile();
  buffer[0]='\0';
  strncat( buffer,mail_user_name,strlen(mail_user_name) );
  strncat( buffer,maildomain,strlen(maildomain));
  strncat(buffer,"\0",1);
  gtk_entry_set_text(GTK_ENTRY (email_feld),buffer);
  gtk_entry_set_text(GTK_ENTRY (header_entry_name),organisation);
  gtk_entry_set_text(GTK_ENTRY (header_entry_street),header_street);
  gtk_entry_set_text(GTK_ENTRY (header_entry_town),header_town);
  
}


void init_config_defaults()
{
  char buffer[500];
  maildomain=(char *)"";
  mail_user_name=getenv("USER");
  gtk_entry_set_text (GTK_ENTRY (anrede_feld), "Sehr geehrte");
  header_street="Strasse";
  header_town="PLZ Stadt";
  header_phone="";
  header_fax="";
  organisation="Muster Werke GMBH";
  sprintf(buffer,"finger  %s > %s/realname.tmp",\
	  mail_user_name,getenv("HOME"));
  system(buffer);
  sprintf(buffer,"%s/realname.tmp",getenv("HOME"));
  gtk_entry_set_text((GtkEntry *)name_feld,(gchar *) \
	     conf_string_get(buffer, "Name:") );
  sprintf(buffer,"rm %s/realname.tmp",getenv("HOME"));
  system(buffer);
}

void init_config_globalfile()
{
  init_config_fromfile("/etc/briefomatrc");
}

void init_config_personalfile()
{
  char configfile[1000]; //vorsicht unsicher bei langen Filenamen
  configfile[0]='\0';
  strcpy(configfile,getenv("HOME"));
  strcat(configfile,"/.briefomatrc");
  init_config_fromfile(configfile);
}

void init_config_fromfile(char *filename)
{
  char buffer[1000];
  if (is_item(filename,"BRIEFKOPF"))
    briefkopf  = (char) conf_long_get(filename,"BRIEFKOPF");
  if (is_item(filename, "MAILDOMAIN"))
    maildomain = conf_string_get(filename,"MAILDOMAIN");
  if(is_item(filename,"SENDER_REAL_NAME"))  
    gtk_entry_set_text((GtkEntry *)name_feld,(gchar *) \
		       conf_string_get(filename, "SENDER_REAL_NAME") );
  if(is_item(filename,"STD_ANREDE"))
   gtk_entry_set_text((GtkEntry *)anrede_feld,(gchar *) \
		       conf_string_get(filename, "STD_ANREDE") );
  if(is_item(filename,"HEADER_NAME"))
    organisation=conf_string_get(filename, "HEADER_NAME");
  if(is_item(filename,"HEADER_STREET"))
    header_street=conf_string_get(filename, "HEADER_STREET");
  if(is_item(filename,"HEADER_TOWN"))
    header_town=conf_string_get(filename, "HEADER_TOWN");
  if(is_item(filename,"HEADER_PHONE"))
    header_phone=conf_string_get(filename, "HEADER_PHONE");
  if(is_item(filename,"HEADER_FAX"))
    header_fax=conf_string_get(filename, "HEADER_FAX");
  if(is_item(filename,"MAIL_USER"))
    mail_user_name=conf_string_get(filename, "MAIL_USER");
    
}










